<?php

namespace Drupal\commerce_stripe_payment_request_button\PluginForm;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;



class PaymentMethodOffsiteForm extends PaymentOffsiteForm {


  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);


    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    $order = $payment->getOrder();
    $amount = $payment->getAmount();

    $form['#attached']['library'][] = 'commerce_stripe_payment_request/form';

    $form['#attached']['drupalSettings']['stripe_payment_request'] = [
      'currencyCode' => $amount->getCurrencyCode(),
      'countryCode' => $order->getStore()->getAddress()->getCountryCode(),
      'store' => $order->getStore()->label(),
      'total' => 0, // @todo: Real total.
      'cancelUrl' => $form['#cancel_url'],
      'successUrl' => Url::fromRoute('commerce_checkout.form', [
        'commerce_order' => $order->id(),
        'step' => 'complete',
      ])->toString(),
      'paymentUrl' => $form['#return_url']
    ];


    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Accept instalments and complete purchase'),
    ];
    $form['actions']['cancel'] = [
      '#type' => 'link',
      '#title' => $this->t('Cancel'),
      '#url' => Url::fromUri($form['#cancel_url']),
    ];



    // $charge_path = 'checkout/' . $order->order_id . '/stripe-payment-request';


    return $form;

  }


  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValue($form['#parents']);
    if (empty($values['cashpresso_token'])) {
      $form_state->setError($form['cashpresso_token'], $this->t('You have to choose instalments first.'));
      return;
    }

    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    /** @var \Drupal\commerce_cashpresso\Plugin\Commerce\PaymentGateway\CashpressoGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();

    $cashpresso_token = $values['cashpresso_token'];
    $success = $payment_gateway_plugin->authorizePayment($payment, $cashpresso_token);
    if (!$success) {
      throw new NeedsRedirectException($form['#exception_url']);
    }
  }


}